#ifndef NT2_INCLUDE_FUNCTIONS_POSMIN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POSMIN_HPP_INCLUDED

#include <nt2/reduction/include/functions/posmin.hpp>

#endif
